#!/bin/bash
#
# tftpd		Start and stop the standalone tftpd-hpa server.
#
# chkconfig:	- 86 14
# description:	H. Peter Anvin's version of BSD TFTP daemon with \
#		RFC 2347 option negotiation, blksize (RFC 2348), \
#		tsize (RFC 2349), and timeout (RFC 2349) options.
# processname: tftpd
# pidfile: /var/run/tftpd.pid
# config: /etc/sysconfig/tftpd
#


# Source function library.
. /etc/init.d/functions

# Source networking configuration and check that networking is up.
if [ -r /etc/sysconfig/network ] ; then
	. /etc/sysconfig/network
	[ ${NETWORKING} = "no" ] && exit 0
fi

if [ -f /etc/sysconfig/tftpd ]; then
   . /etc/sysconfig/tftpd
fi


RETVAL=0

start() {
        # Start daemons.
        echo -n $"Starting tftpd: "
	daemon tftpd -v -l -u $TFTPDUSER -s $TFTPDCHROOT
	RETVAL=$?
	echo
	[ $RETVAL -eq 0 ] && touch /var/lock/subsys/tftpd
	return $RETVAL
}

stop() {
        # Stop daemons.
	echo -n $"Stopping tftpd: "
	killproc tftpd
	RETVAL=$?
	echo
        [ $RETVAL -eq 0 ] && rm -f /var/lock/subsys/tftpd
	return $RETVAL
}

restart() {
	stop
	start
}


# See how we were called.
case "$1" in
    start)
        start
        ;;
    stop)
        stop
        ;;
    status)
        status tftpd
	;;
    restart)
	restart
	;;
    condrestart)
        [ -f /var/lock/subsys/tftpd ] && restart || :
	;;
    *)
	echo $"Usage: $0 {start|stop|restart|status|condrestart}"
	exit 1
esac

exit $?

